@@ -4,12 +4,12 @@ import sys
 
 import agate
 
-from csvkit.cli import CSVKitUtility, make_default_headers
+from csvkit.cli import QUOTING_CHOICES, CSVKitUtility, make_default_headers
 
 
 class CSVFormat(CSVKitUtility):
     description = 'Convert a CSV file to a custom output format.'
-    override_flags = ['L', 'blanks', 'date-format', 'datetime-format']
+    override_flags = ['I']
 
     def add_arguments(self):
         self.argparser.add_argument(
@@ -29,9 +29,9 @@ class CSVFormat(CSVKitUtility):
             '-Q', '--out-quotechar', dest='out_quotechar',
             help='Character used to quote strings in the output file.')
         self.argparser.add_argument(
-            '-U', '--out-quoting', dest='out_quoting', type=int, choices=[0, 1, 2, 3],
-            help='Quoting style used in the output file. 0 = Quote Minimal, 1 = Quote All, '
-                 '2 = Quote Non-numeric, 3 = Quote None.')
+            '-U', '--out-quoting', dest='out_quoting', type=int, choices=QUOTING_CHOICES,
+            help='Quoting style used in the output file: 0 quote minimal, 1 quote all, '
+                 '2 quote non-numeric, 3 quote none.')
         self.argparser.add_argument(
             '-B', '--out-no-doublequote', dest='out_doublequote', action='store_false',
             help='Whether or not double quotes are doubled in the output file.')
@@ -72,18 +72,33 @@ class CSVFormat(CSVKitUtility):
         if self.additional_input_expected():
             sys.stderr.write('No input file or piped data provided. Waiting for standard input:\n')
 
-        reader = agate.csv.reader(self.skip_lines(), **self.reader_kwargs)
         writer = agate.csv.writer(self.output_file, **self.writer_kwargs)
-        if self.args.no_header_row:
-            # Peek at a row to get the number of columns.
-            _row = next(reader)
-            headers = make_default_headers(len(_row))
-            reader = itertools.chain([headers, _row], reader)
 
-        if self.args.skip_header:
-            next(reader)
+        if self.args.out_quoting == 2:
+            table = agate.Table.from_csv(
+                self.input_file,
+                skip_lines=self.args.skip_lines,
+                column_types=self.get_column_types(),
+                **self.reader_kwargs,
+            )
 
-        writer.writerows(reader)
+            # table.to_csv() has no option to omit the column names.
+            if not self.args.skip_header:
+                writer.writerow(table.column_names)
+
+            writer.writerows(table.rows)
+        else:
+            reader = agate.csv.reader(self.skip_lines(), **self.reader_kwargs)
+            if self.args.no_header_row:
+                # Peek at a row to get the number of columns.
+                _row = next(reader)
+                headers = make_default_headers(len(_row))
+                reader = itertools.chain([headers, _row], reader)
+
+            if self.args.skip_header:
+                next(reader)
+
+            writer.writerows(reader)
 
 
 def launch_new_instance():
